@@ -13,3 +13,5 @@ EXPLAIN_SUPPORTED_STATEMENTS = (
     "UPDATE",
     "DELETE",
 )
+SENTRY_DSN = None  # This value is injected during the publishing process
+SENTRY_DSN = "https://f4732683eb3a40ab9e5a5d4033b246e0@o1173646.ingest.sentry.io/6271090"
